==> moodle-1.5-mysql.tgz: moodle/lang/de/scorm.php <==
<?PHP // $Id$ 
      // scorm.php - created with Moodle 1.5 ALPHA (2005051500)


$string['asset'] = 'Asset';
$string['attr_error'] = 'Falscher Wert fr Attribut ($a->attr) in Tag $a->tag';
$string['autocontinue'] = 'Automatische Fortsetzung';
$string['badmanifest'] = 'Einige dauerhafte Fehler: siehe Fehlerprotokoll';
$string['browse'] = 'Durchsuchen';
$string['browsed'] = 'Durchsucht';
$string['browsemode'] = 'Durchsuchen Einstellung';
$string['chooseapacket'] = 'Auswhlen oder aktualisieren eines SCORM Pakets';
$string['completed'] = 'Abgeschlossen';
$string['coursepacket'] = 'Kurspaket';
$string['coursestruct'] = 'Kursstruktur';
$string['datadir'] = 'Dateisystemfehler: Verzeichnis fr Kursdaten konnte nicht erstellt werden';
$string['details'] = 'SCO Track Details';
$string['display'] = 'Anzeige';
$string['domxml'] = 'DOMXML externe Bibliothek';
$string['enablebrowse'] = 'Vorschaumodus aktivieren';
$string['entercourse'] = 'SCORM Kurs starten';
$string['errorlogs'] = 'Fehlerprotokoll';
$string['exit'] = 'SCORM-Kurs beenden';
$string['expcoll'] = 'Entfalten/Zusammensetzen';
$string['failed'] = 'Fehlgeschlagen';
$string['firstaccess'] = 'Erster Versuch';
$string['found'] = 'Manifest gefunden';
$string['frameheight'] = 'Diese Einstellung definiert die Hhe des SCO-Frames';
$string['framewidth'] = 'Diese Einstellung definiert die Breite des SCO-Frames';
$string['gradeaverage'] = 'Durchschnittsnote';
$string['gradehighest'] = 'Hchstnote';
$string['grademethod'] = 'Bewertungsmethode';
$string['gradescoes'] = 'Scoes Situation';
$string['gradesum'] = 'Summe der Bewertungen';
$string['guestsno'] = 'Gste knnen Scorm-Kurse nicht ansehen';
$string['height'] = 'Hhe';
$string['incomplete'] = 'Unvollstndig';
$string['lastaccess'] = 'Letzter Versuch';
$string['missing_attribute'] = 'Fehlende Attribute $a->attr in Tag $a->tag';
$string['missing_tag'] = 'Fehlendes Tag $a->tag';
$string['mode'] = 'Einstellung';
$string['modulename'] = 'SCORM';
$string['modulenameplural'] = 'SCORMS';
$string['next'] = 'Fortsetzen';
$string['no_attributes'] = 'Tag $a->tag muss Attribute haben';
$string['no_children'] = 'Tag $a->tag muss Kinder (children) haben';
$string['noactivity'] = 'Nichts zu berichten';
$string['nomanifest'] = 'Zeichen nicht gefunden';
$string['noreports'] = 'Kein Bericht zum Anzeigen vorhanden';
$string['normal'] = 'Normal';
$string['not_corr_type'] = 'Falsche Schreibweise im Tag $a->tag';
$string['notattempted'] = 'Nicht versucht';
$string['organization'] = 'Organisation';
$string['organizations'] = 'Organisationen';
$string['packagedir'] = 'Dateisystemfehler: Verzeichnis fr Paket kann nicht erstellt werden';
$string['passed'] = 'Abgeschlossen';
$string['php5'] = 'PHP 5 (DOMXML native library)';
$string['popup'] = 'Diesen SCO in einem neuen Fenster ffnen';
$string['position_error'] = 'Der $a-tag Tag kann nicht Kind/Child des $a->parent Tag sein';
$string['prev'] = 'Vorheriges';
$string['regular'] = 'Regulres Zeichen';
$string['report'] = 'Bericht';
$string['review'] = 'Rckblick';
$string['scoes'] = 'Scoes';
$string['score'] = 'Bewertung';
$string['syntax'] = 'Schreibfehler';
$string['tag_error'] = 'Unbekannter Tag ($a->tag) mit dem Inhalt: $a->value';
$string['too_many_attributes'] = 'Tag $a->tag hat zu viele Attribute';
$string['too_many_children'] = 'Tag $a->tag hat zu viele Kinder/children';
$string['totaltime'] = 'Zeit';
$string['trackingloose'] = 'WARNUNG: Trackingdaten dieses SCORM Paketes gehen verloren!';
$string['validateascorm'] = 'berprfen eines SCORM Pakets';
$string['validation'] = 'Prfergebnis';
$string['validationtype'] = 'Die Einstellungen der DOMXML Library werden zur Prfung des SCORM Manifests  verwandt. Wenn Sie sich nicht genau auskennen, lassen Sie die Einstellungen unverndert stehen.';
$string['versionwarning'] = 'Die Version des Manifests ist lter als 1.3, Warnung beim $a->tag Tag';
$string['viewallreports'] = 'Berichte fr $a Versuche anzeigen';
$string['width'] = 'Breite';

?>

==> moodle-1.5.3-mysql.tgz: moodle/lang/de/scorm.php <==
<?PHP // $Id$ 
      // scorm.php - created with Moodle 1.5.1 (2005060210)


$string['advanced'] = 'Weitere Einstellungen';
$string['asset'] = 'Asset';
$string['attr_error'] = 'Falscher Wert fr Attribut ($a->attr) in Tag $a->tag';
$string['autocontinue'] = 'Automatische Fortsetzung';
$string['badmanifest'] = 'Einige dauerhafte Fehler: siehe Fehlerprotokoll';
$string['browse'] = 'Durchsuchen';
$string['browsed'] = 'Durchsucht';
$string['browsemode'] = 'Durchsuchen Einstellung';
$string['chooseapacket'] = 'Auswhlen/aktualisieren eines SCORM Pakets';
$string['completed'] = 'Abgeschlossen';
$string['coursepacket'] = 'Kurspaket';
$string['coursestruct'] = 'Kursstruktur';
$string['datadir'] = 'Dateisystemfehler: Verzeichnis fr Kursdaten konnte nicht erstellt werden';
$string['details'] = 'SCO Track Details';
$string['display'] = 'Anzeige';
$string['domxml'] = 'DOMXML externe Bibliothek';
$string['enablebrowse'] = 'Vorschaumodus aktivieren';
$string['entercourse'] = 'SCORM Kurs starten';
$string['errorlogs'] = 'Fehlerprotokoll';
$string['exit'] = 'SCORM-Kurs beenden';
$string['expcoll'] = 'Entfalten/Zusammensetzen';
$string['failed'] = 'Fehlgeschlagen';
$string['firstaccess'] = 'Erster Versuch';
$string['found'] = 'Manifest gefunden';
$string['frameheight'] = 'Diese Einstellung definiert die Hhe des SCO-Frames';
$string['framewidth'] = 'Diese Einstellung definiert die Breite des SCO-Frames';
$string['gradeaverage'] = 'Durchschnittsnote';
$string['gradehighest'] = 'Hchstnote';
$string['grademethod'] = 'Bewertungsmethode';
$string['gradescoes'] = 'Scoes Situation';
$string['gradesum'] = 'Summe der Bewertungen';
$string['guestsno'] = 'Gste knnen Scorm-Kurse nicht ansehen';
$string['height'] = 'Hhe';
$string['incomplete'] = 'Unvollstndig';
$string['lastaccess'] = 'Letzter Versuch';
$string['missing_attribute'] = 'Fehlende Attribute $a->attr in Tag $a->tag';
$string['missing_tag'] = 'Fehlendes Tag $a->tag';
$string['mode'] = 'Einstellung';
$string['modulename'] = 'SCORM';
$string['modulenameplural'] = 'SCORMS';
$string['next'] = 'Fortsetzen';
$string['no_attributes'] = 'Tag $a->tag muss Attribute haben';
$string['no_children'] = 'Tag $a->tag muss Kinder (children) haben';
$string['noactivity'] = 'Nichts zu berichten';
$string['nomanifest'] = 'Zeichen nicht gefunden';
$string['noreports'] = 'Kein Bericht zum Anzeigen vorhanden';
$string['normal'] = 'Normal';
$string['not_corr_type'] = 'Falsche Schreibweise im Tag $a->tag';
$string['notattempted'] = 'Nicht versucht';
$string['organization'] = 'Organisation';
$string['organizations'] = 'Organisationen';
$string['packagedir'] = 'Dateisystemfehler: Verzeichnis fr Paket kann nicht erstellt werden';
$string['packagefile'] = 'Keine Paket Datei ausgewhlt';
$string['passed'] = 'Abgeschlossen';
$string['php5'] = 'PHP 5 (DOMXML native library)';
$string['popup'] = 'Dieses Lernobjekt in einem neuen Fenster ffnen';
$string['position_error'] = 'Der $a-tag Tag kann nicht Kind/Child des $a->parent Tag sein';
$string['prev'] = 'Vorheriges';
$string['regular'] = 'Regulres Zeichen';
$string['report'] = 'Bericht';
$string['review'] = 'Rckblick';
$string['scoes'] = 'Scoes';
$string['score'] = 'Bewertung';
$string['scormcourse'] = 'SCORM Kurs';
$string['stagesize'] = 'Frame/Fenster Gre';
$string['syntax'] = 'Schreibfehler';
$string['tag_error'] = 'Unbekannter Tag ($a->tag) mit dem Inhalt: $a->value';
$string['too_many_attributes'] = 'Tag $a->tag hat zu viele Attribute';
$string['too_many_children'] = 'Tag $a->tag hat zu viele Kinder/children';
$string['totaltime'] = 'Zeit';
$string['trackingloose'] = 'WARNUNG: Trackingdaten dieses SCORM Paketes gehen verloren!';
$string['validateascorm'] = 'berprfen eines SCORM Pakets';
$string['validation'] = 'Prfergebnis';
$string['validationtype'] = 'Die Einstellungen der DOMXML Library werden zur Prfung des SCORM Manifests  verwandt. Wenn Sie sich nicht genau auskennen, lassen Sie die Einstellungen unverndert stehen.';
$string['versionwarning'] = 'Die Version des Manifests ist lter als 1.3, Warnung beim $a->tag Tag';
$string['viewallreports'] = 'Berichte fr $a Versuche anzeigen';
$string['width'] = 'Breite';

?>
